==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/PortworxVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface PortworxVolumeSourceFluent<A extends PortworxVolumeSourceFluent<A>> extends Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getVolumeID();
    public A withVolumeID(String volumeID);
    public Boolean hasVolumeID();
    public A withNewVolumeID(StringBuilder arg1);
    public A withNewVolumeID(int[] arg1,int arg2,int arg3);
    public A withNewVolumeID(char[] arg1);
    public A withNewVolumeID(StringBuffer arg1);
    public A withNewVolumeID(byte[] arg1,int arg2);
    public A withNewVolumeID(byte[] arg1);
    public A withNewVolumeID(char[] arg1,int arg2,int arg3);
    public A withNewVolumeID(byte[] arg1,int arg2,int arg3);
    public A withNewVolumeID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVolumeID(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/PortworxVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface PortworxVolumeSourceFluent<A extends PortworxVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public String getVolumeID();
    public A withVolumeID(String volumeID);
    public Boolean hasVolumeID();
    public A withNewVolumeID(StringBuilder arg1);
    public A withNewVolumeID(int[] arg1,int arg2,int arg3);
    public A withNewVolumeID(char[] arg1);
    public A withNewVolumeID(StringBuffer arg1);
    public A withNewVolumeID(byte[] arg1,int arg2);
    public A withNewVolumeID(byte[] arg1);
    public A withNewVolumeID(char[] arg1,int arg2,int arg3);
    public A withNewVolumeID(byte[] arg1,int arg2,int arg3);
    public A withNewVolumeID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVolumeID(String arg1);
}
